<h1 align="center">
  <img src="./docs/pics/brand.svg">
</h1>

<h3 align="center">stage sep(aration) x</h3>
<p align="center">
    <em>detect stages in video automatically</em>
</p>

---

[![PyPI version](https://badge.fury.io/py/stagesepx.svg)](https://badge.fury.io/py/stagesepx)
![actions](https://action-badges.now.sh/williamfzc/stagesepx)
[![Maintainability](https://api.codeclimate.com/v1/badges/ef27756ce9a4f7f4ba94/maintainability)](https://codeclimate.com/github/williamfzc/stagesepx/maintainability)

---

## 分析你的视频

[![openAmazonFromChrome.gif](https://i.loli.net/2019/07/17/5d2e8ed1e9d0b49825.gif)](https://i.loli.net/2019/07/17/5d2e8ed1e9d0b49825.gif)

## 提取出稳定阶段与变化阶段

![report1.png](https://i.loli.net/2019/08/30/SpPBsuJRKvWfLT5.png)

## 耗时计算与详细的图表展示

![report2.png](https://i.loli.net/2019/08/30/whD9oSOLlJFQip2.png)

## 支持几乎任何视频

[![pen.gif](https://i.loli.net/2019/07/22/5d35a84e3e0df82450.gif)](https://i.loli.net/2019/07/22/5d35a84e3e0df82450.gif)

[![pen_chart.png](https://i.loli.net/2019/07/22/5d35a8858640e67521.png)](https://i.loli.net/2019/07/22/5d35a8858640e67521.png)

---

- 全自动，无需前置训练与学习
- 更少的代码
- 所有你需要的，只是一个视频

从 [官方文档](https://williamfzc.github.io/stagesepx/) 开始吧！

## License

[MIT](LICENSE)
